
/**
 * Hoofdklasse van de toepassing. Vormt de interface met de elektronica van een schaakklok.
 * 
 * Dit is een alternatieve versie die van de reguliere die verschilt in de volgende punten:
 * <ul>
 *   <li>De speler wordt niet bijgehouden als een getal (1/2) maar als een logische
 *   waarde.</li>
 *   <li>Cijferparen hebben een herstart-methode die bij de minuten de teller op 6 plaatst,
 *   en bij de seconden op 0. De herstartwaarde (0 of 6) wordt meegegeven met de constructor.</li>
 *   <li>De cijferparen tellen automatisch af van 0 naar 59.</li>
 *   <li>De methode geefWaarde van Cijferpaar wordt vervangen door isNul.</li>
 * </ul>
 * 
 * 2016 (c) Kris Coolsaet Universiteit Gent
 */
public class Schaakklok {
    
    // Velden
    ///////////
    
    private boolean isWit; // huidige speler
    
    private Klokje wit;
    
    private Klokje zwart;
    
    // Constructoren
    ////////////////
    
    /**
     * Constructor. Initialiseert de velden van dit object.
     */
    public Schaakklok() {
        wit = new Klokje();
        zwart = new Klokje();
        isWit = true;
    }
    
    // Methoden
    ///////////
    
    /**
     * Wordt opgeroepen wanneer een nieuwe wedstrijd begint.
     */
    public void herstart() {
        wit.herstart();
        zwart.herstart();
        isWit = true;
    }
    
    /**
     * Wordt elke seconde opgeroepen.
     */
    public void ontvangPuls() {
        if (isWit) {
            wit.ontvangPuls();
        } else {
            zwart.ontvangPuls();
        }
    }
    
    /**
     * Geef terug wat er op het display moet komen voor de opgegeven speler
     * @param w true wanneer je wit bedoelt, false voor zwart
     */
    public String geefTijd(boolean w) {
        if (isWit) {
            return wit.geefTijd();
        } else {
            return zwart.geefTijd();
        }
    }
    
    /**
     * Geeft aan dat er een andere speler aan zet is
     */
    public void wisselSpeler() {
        isWit = ! isWit; // uitroepteken betekent 'niet' en wisselt dus true en false om.
    }

}
